-- To view the current session settings use
DBCC USEROPTIONS

-- To use Indexed on Views or Indexed on Computed Columns
-- you must have consistency from client applications. More
-- than anything it is best that you feel comfortable with the
-- required environment. 

-- The following examples show you supported syntax for each
-- of the required session settings. Please see the books online
-- for additional information for each of these!

-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-- ANSI_NULLS 
--	Controls the behavior with regard to NULLs.

SET ANSI_NULLS ON
SELECT * FROM pubs.dbo.titles WHERE price = NULL
	-- is NOT supported
SELECT * FROM pubs.dbo.titles WHERE price IS NULL
	-- MUST be used

-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-- ANSI_PADDING
--	Controls the behavior with regard to trailing blanks in column definitions

-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-- ANSI_WARNING
--	Controls

-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-- ARITHABORT
--	Controls

-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-- CONCAT_NULL_YIELDS_NULL
--	Controls how string concatenation with NULL values is
--	handled.

SET CONCAT_NULL_YIELDS_NULL ON
SELECT 'hello ' + NULL
	-- returns NULL
SET CONCAT_NULL_YIELDS_NULL OFF
SELECT 'hello ' + NULL
	-- returns 'hello'
SET CONCAT_NULL_YIELDS_NULL ON
go

-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-- QUOTED_IDENTIFIER
--	Controls how identifiers are recognized
SET QUOTED_IDENTIFIER ON
SELECT * FROM pubs.dbo.authors AS a WHERE a.au_lname = "O'Leary"
	-- returns an error because the string in " is recognized as the 
	-- identifier. There is no colmn named O'Leary
	-- Double quotes are NOT supported as a string delimiter.
SELECT * FROM pubs.dbo.authors AS a WHERE a.au_lname = 'O''Leary'
	-- All quotes within quotes should be two single quotes

SET QUOTED_IDENTIFIER OFF
SELECT * FROM pubs.dbo.authors AS a WHERE a.au_lname = "O'Leary"
	-- works but then indexes on views/computed columns not supported

-- ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Session Setting that must be off:
NUMERIC_ROUNDABORT
	See BOL Topic SET Options that Affect Results
